summaryrefslogtreecommitdiff
path: root/numpy/linalg
diff options
context:
space:
mode:
authorDimitri Papadopoulos <3234522+DimitriPapadopoulos@users.noreply.github.com>2021-09-21 09:18:37 +0200
committerDimitri Papadopoulos <3234522+DimitriPapadopoulos@users.noreply.github.com>2021-09-21 20:29:43 +0200
commit83960267dc097742cb67ef575504afa56f82b102 (patch)
tree5de763d6385fc3fc630db0992cd6b2d2ff765ea6 /numpy/linalg
parente467a284d1a2055337ce73cd92aadb491aa9a776 (diff)
downloadnumpy-83960267dc097742cb67ef575504afa56f82b102.tar.gz
DOC: Typos found by codespell
Diffstat (limited to 'numpy/linalg')
-rw-r--r--numpy/linalg/linalg.py4
-rw-r--r--numpy/linalg/linalg.pyi2
-rw-r--r--numpy/linalg/tests/test_linalg.py8
3 files changed, 7 insertions, 7 deletions
diff --git a/numpy/linalg/linalg.py b/numpy/linalg/linalg.py
index 2b686839a..95780d19d 100644
--- a/numpy/linalg/linalg.py
+++ b/numpy/linalg/linalg.py
@@ -1864,7 +1864,7 @@ def matrix_rank(A, tol=None, hermitian=False):
References
----------
- .. [1] MATLAB reference documention, "Rank"
+ .. [1] MATLAB reference documentation, "Rank"
https://www.mathworks.com/help/techdoc/ref/rank.html
.. [2] W. H. Press, S. A. Teukolsky, W. T. Vetterling and B. P. Flannery,
"Numerical Recipes (3rd edition)", Cambridge University Press, 2007,
@@ -2159,7 +2159,7 @@ def lstsq(a, b, rcond="warn"):
r"""
Return the least-squares solution to a linear matrix equation.
- Computes the vector `x` that approximatively solves the equation
+ Computes the vector `x` that approximately solves the equation
``a @ x = b``. The equation may be under-, well-, or over-determined
(i.e., the number of linearly independent rows of `a` can be less than,
equal to, or greater than its number of linearly independent columns).
diff --git a/numpy/linalg/linalg.pyi b/numpy/linalg/linalg.pyi
index a35207d32..a60b9539e 100644
--- a/numpy/linalg/linalg.pyi
+++ b/numpy/linalg/linalg.pyi
@@ -97,7 +97,7 @@ def inv(a: _ArrayLikeFloat_co) -> NDArray[floating[Any]]: ...
@overload
def inv(a: _ArrayLikeComplex_co) -> NDArray[complexfloating[Any, Any]]: ...
-# TODO: The supported input and output dtypes are dependant on the value of `n`.
+# TODO: The supported input and output dtypes are dependent on the value of `n`.
# For example: `n < 0` always casts integer types to float64
def matrix_power(
a: _ArrayLikeComplex_co | _ArrayLikeObject_co,
diff --git a/numpy/linalg/tests/test_linalg.py b/numpy/linalg/tests/test_linalg.py
index dd059fb63..a45323bb3 100644
--- a/numpy/linalg/tests/test_linalg.py
+++ b/numpy/linalg/tests/test_linalg.py
@@ -1956,8 +1956,8 @@ class TestMultiDot:
assert_almost_equal(multi_dot([A, B]), A.dot(B))
assert_almost_equal(multi_dot([A, B]), np.dot(A, B))
- def test_basic_function_with_dynamic_programing_optimization(self):
- # multi_dot with four or more arguments uses the dynamic programing
+ def test_basic_function_with_dynamic_programming_optimization(self):
+ # multi_dot with four or more arguments uses the dynamic programming
# optimization and therefore deserve a separate
A = np.random.random((6, 2))
B = np.random.random((2, 6))
@@ -2018,8 +2018,8 @@ class TestMultiDot:
assert_almost_equal(out, A.dot(B))
assert_almost_equal(out, np.dot(A, B))
- def test_dynamic_programing_optimization_and_out(self):
- # multi_dot with four or more arguments uses the dynamic programing
+ def test_dynamic_programming_optimization_and_out(self):
+ # multi_dot with four or more arguments uses the dynamic programming
# optimization and therefore deserve a separate test
A = np.random.random((6, 2))
B = np.random.random((2, 6))